@@ -19,12 +19,11 @@ def open_xlsx(filename, read_only=False) -> Workbook:
     reader = ExcelReader(filename, read_only=read_only)
     reader.read()
     wb = reader.wb
-    type_check = isinstance(wb, Workbook)
     wb.filename = filename
     # data_only copy is opened for reading cached formula results
-    reader_data_only = ExcelReader(filename, read_only=read_only, data_only=True)
-    reader_data_only.read()
-    wb_data_only = reader_data_only.wb
-    for name in wb.sheetnames:
-        wb[name].data_only_copy = wb_data_only[name]
+    # reader_data_only = ExcelReader(filename, read_only=read_only, data_only=True)
+    # reader_data_only.read()
+    # wb_data_only = reader_data_only.wb
+    # for name in wb.sheetnames:
+    #     wb[name].data_only_copy = wb_data_only[name]
     return wb
\ No newline at end of file
